<!--
  Thank you for contributing to easy-release-automation

  Please ensure your pull request follows the guidelines below to help us review it effectively.
-->

## Description

<!--
  Provide a clear and concise description of the changes introduced by this pull request.
  Include the context and the problem it solves.
-->

## Related Issue

<!--
  If your pull request addresses an issue, link it here.
  Example: Fixes #123
-->

## Type of Change

<!--
  Please delete options that are not relevant.
-->

- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to change)
- [ ] Documentation update
- [ ] Refactoring / Code quality improvement
- [ ] Other (please describe):

## Checklist

<!--
  Please ensure all the following tasks are completed before submitting your pull request.
  You can mark them as done by replacing [ ] with [x].
-->

- [ ] **I have readed the CONTRIBUTING.md documentation**
- [ ] **I have performed a self-review of my own code.**
- [ ] **I have commented my code, particularly in hard-to-understand areas.**
- [ ] **I have made corresponding changes to the documentation.**
- [ ] **My changes generate no new warnings.**
- [ ] **I have updated the Changelog.**

## Screenshots (if applicable)

<!--
  Add screenshots to help explain your changes if applicable.
-->
